==> dojo-1.10.6.tgz: package/cldr/nls/hr/hebrew.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"field-second-relative+0": "sada",
	"quarters-standAlone-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"field-weekday": "Dan u tjednu",
	"field-wed-relative+0": "ova srijeda",
	"field-wed-relative+1": "sljedeća srijeda",
	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-tue-relative+-1": "prošli utorak",
	"days-format-short": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"dateFormat-long": "d. MMMM y. G",
	"field-fri-relative+-1": "prošli petak",
	"field-wed-relative+-1": "prošla srijeda",
	"dateFormatItem-yyyyQQQ": "QQQ y. G",
	"dateFormat-full": "EEEE, d. MMMM y. G",
	"dateFormatItem-yyyyMEd": "E, d. M. y. G",
	"field-thu-relative+-1": "prošli četvrtak",
	"dateFormatItem-Md": "d. M.",
	"dayPeriods-format-wide-noon": "podne",
	"field-era": "Era",
	"quarters-format-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"field-year": "Godina",
	"field-hour": "Sat",
	"field-sat-relative+0": "ova subota",
	"field-sat-relative+1": "sljedeća subota",
	"field-day-relative+0": "danas",
	"field-thu-relative+0": "ovaj četvrtak",
	"field-day-relative+1": "sutra",
	"field-thu-relative+1": "sljedeći četvrtak",
	"dateFormatItem-GyMMMd": "d. MMM y. G",
	"field-day-relative+2": "prekosutra",
	"quarters-format-abbr": [
		"1kv",
		"2kv",
		"3kv",
		"4kv"
	],
	"quarters-standAlone-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"dateFormatItem-Gy": "y. G",
	"dateFormatItem-yyyyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-M": "L.",
	"days-standAlone-wide": [
		"nedjelja",
		"ponedjeljak",
		"utorak",
		"srijeda",
		"četvrtak",
		"petak",
		"subota"
	],
	"dateFormatItem-yyyyMMM": "LLL y. G",
	"dateFormatItem-yyyyMMMd": "d. MMM y. G",
	"dayPeriods-format-abbr-noon": "podne",
	"field-sun-relative+0": "ova nedjelja",
	"field-sun-relative+1": "sljedeća nedjelja",
	"quarters-standAlone-abbr": [
		"1kv",
		"2kv",
		"3kv",
		"4kv"
	],
	"eraAbbr": [
		"AM"
	],
	"field-minute": "Minuta",
	"field-dayperiod": "Prijepodne/popodne",
	"days-standAlone-abbr": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"dateFormatItem-d": "d.",
	"quarters-format-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"field-day-relative+-1": "jučer",
	"dateFormatItem-h": "hh a",
	"field-day-relative+-2": "prekjučer",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E, d. M.",
	"field-fri-relative+0": "ovaj petak",
	"field-fri-relative+1": "sljedeći petak",
	"field-day": "Dan",
	"days-format-wide": [
		"nedjelja",
		"ponedjeljak",
		"utorak",
		"srijeda",
		"četvrtak",
		"petak",
		"subota"
	],
	"field-zone": "Vremenska zona",
	"dateFormatItem-y": "y. G",
	"field-year-relative+-1": "prošle godine",
	"field-month-relative+-1": "prošli mjesec",
	"dateFormatItem-hm": "hh:mm a",
	"days-format-abbr": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"days-format-narrow": [
		"N",
		"P",
		"U",
		"S",
		"Č",
		"P",
		"S"
	],
	"dateFormatItem-yyyyMd": "d. M. y. G",
	"field-month": "Mjesec",
	"days-standAlone-narrow": [
		"n",
		"p",
		"u",
		"s",
		"č",
		"p",
		"s"
	],
	"field-tue-relative+0": "ovaj utorak",
	"field-tue-relative+1": "sljedeći utorak",
	"field-mon-relative+0": "ovaj ponedjeljak",
	"field-mon-relative+1": "sljedeći ponedjeljak",
	"dateFormat-short": "d.M.y. GGGGG",
	"field-second": "Sekunda",
	"field-sat-relative+-1": "prošla subota",
	"field-sun-relative+-1": "prošla nedjelja",
	"field-month-relative+0": "ovaj mjesec",
	"field-month-relative+1": "sljedeći mjesec",
	"dateFormatItem-Ed": "E, d.",
	"field-week": "Tjedan",
	"dateFormat-medium": "d. M. y. G",
	"field-year-relative+0": "ove godine",
	"field-week-relative+-1": "prošli tjedan",
	"dateFormatItem-yyyyM": "M. y. G",
	"field-year-relative+1": "sljedeće godine",
	"dateFormatItem-yyyyQQQQ": "QQQQ y. G",
	"dateFormatItem-hms": "hh:mm:ss a",
	"dateFormatItem-GyMMM": "LLL y. G",
	"field-mon-relative+-1": "prošli ponedjeljak",
	"dateFormatItem-yyyy": "y. G",
	"field-week-relative+0": "ovaj tjedan",
	"field-week-relative+1": "sljedeći tjedan"
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/hr/hebrew.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"field-second-relative+0": "sada",
	"quarters-standAlone-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"field-weekday": "Dan u tjednu",
	"field-wed-relative+0": "ova srijeda",
	"field-wed-relative+1": "sljedeća srijeda",
	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-tue-relative+-1": "prošli utorak",
	"days-format-short": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"dateFormat-long": "d. MMMM y. G",
	"field-fri-relative+-1": "prošli petak",
	"field-wed-relative+-1": "prošla srijeda",
	"dateFormatItem-yyyyQQQ": "QQQ y. G",
	"dateFormat-full": "EEEE, d. MMMM y. G",
	"dateFormatItem-yyyyMEd": "E, dd.MM.y. GGGGG",
	"field-thu-relative+-1": "prošli četvrtak",
	"dateFormatItem-Md": "dd.MM.",
	"dayPeriods-format-wide-noon": "podne",
	"field-era": "Era",
	"quarters-format-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"field-year": "Godina",
	"field-hour": "Sat",
	"field-sat-relative+0": "ova subota",
	"field-sat-relative+1": "sljedeća subota",
	"field-day-relative+0": "danas",
	"field-thu-relative+0": "ovaj četvrtak",
	"field-day-relative+1": "sutra",
	"field-thu-relative+1": "sljedeći četvrtak",
	"dateFormatItem-GyMMMd": "d. MMM y. G",
	"field-day-relative+2": "prekosutra",
	"quarters-format-abbr": [
		"1kv",
		"2kv",
		"3kv",
		"4kv"
	],
	"quarters-standAlone-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"dateFormatItem-Gy": "y. G",
	"dateFormatItem-yyyyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-M": "L.",
	"days-standAlone-wide": [
		"nedjelja",
		"ponedjeljak",
		"utorak",
		"srijeda",
		"četvrtak",
		"petak",
		"subota"
	],
	"dateFormatItem-yyyyMMM": "LLL y. G",
	"dateFormatItem-yyyyMMMd": "d. MMM y. G",
	"dayPeriods-format-abbr-noon": "podne",
	"field-sun-relative+0": "ova nedjelja",
	"field-sun-relative+1": "sljedeća nedjelja",
	"quarters-standAlone-abbr": [
		"1kv",
		"2kv",
		"3kv",
		"4kv"
	],
	"eraAbbr": [
		"AM"
	],
	"field-minute": "Minuta",
	"field-dayperiod": "AM/PM",
	"days-standAlone-abbr": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"dateFormatItem-d": "d.",
	"quarters-format-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"field-day-relative+-1": "jučer",
	"dateFormatItem-h": "hh a",
	"field-day-relative+-2": "prekjučer",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E, dd.MM.",
	"field-fri-relative+0": "ovaj petak",
	"field-fri-relative+1": "sljedeći petak",
	"field-day": "Dan",
	"days-format-wide": [
		"nedjelja",
		"ponedjeljak",
		"utorak",
		"srijeda",
		"četvrtak",
		"petak",
		"subota"
	],
	"field-zone": "Vremenska zona",
	"dateFormatItem-y": "y. G",
	"field-year-relative+-1": "prošle godine",
	"field-month-relative+-1": "prošli mjesec",
	"dateFormatItem-hm": "hh:mm a",
	"days-format-abbr": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"days-format-narrow": [
		"N",
		"P",
		"U",
		"S",
		"Č",
		"P",
		"S"
	],
	"dateFormatItem-yyyyMd": "dd.MM.y. GGGGG",
	"field-month": "Mjesec",
	"days-standAlone-narrow": [
		"n",
		"p",
		"u",
		"s",
		"č",
		"p",
		"s"
	],
	"field-tue-relative+0": "ovaj utorak",
	"field-tue-relative+1": "sljedeći utorak",
	"field-mon-relative+0": "ovaj ponedjeljak",
	"field-mon-relative+1": "sljedeći ponedjeljak",
	"dateFormat-short": "dd.MM.y. GGGGG",
	"field-second": "Sekunda",
	"field-sat-relative+-1": "prošla subota",
	"field-sun-relative+-1": "prošla nedjelja",
	"field-month-relative+0": "ovaj mjesec",
	"field-month-relative+1": "sljedeći mjesec",
	"dateFormatItem-Ed": "E, d.",
	"field-week": "Tjedan",
	"dateFormat-medium": "d. M. y. G",
	"field-year-relative+0": "ove godine",
	"field-week-relative+-1": "prošli tjedan",
	"dateFormatItem-yyyyM": "MM.y. GGGGG",
	"field-year-relative+1": "sljedeće godine",
	"dateFormatItem-yyyyQQQQ": "QQQQ y. G",
	"dateFormatItem-hms": "hh:mm:ss a",
	"dateFormatItem-GyMMM": "LLL y. G",
	"field-mon-relative+-1": "prošli ponedjeljak",
	"dateFormatItem-yyyy": "y. G",
	"field-week-relative+0": "ovaj tjedan",
	"field-week-relative+1": "sljedeći tjedan"
}
//end v1.x content
);
